@@ -15,5 +15,6 @@
 #' list.if(x,min(score$c1,score$c2) >= 8)
 #' }
 list.if <- function(.data,cond,use.names=TRUE) {
-  list.if.internal(.data,substitute(cond),use.names)
+  items <- list.if.internal(.data,substitute(cond))
+  if(use.names) setnames(items,names(.data)) else items
 }
